@@ -9,6 +9,12 @@ from typing import TYPE_CHECKING, Any, Callable, Optional
 from pydantic import Field, PrivateAttr
 
 from firebolt.common.exception import NoAttachedDatabaseError
+from firebolt.common.urls import (
+    ACCOUNT_ENGINE_START_URL,
+    ACCOUNT_ENGINE_STOP_URL,
+    ACCOUNT_ENGINE_URL,
+)
+from firebolt.db import Connection, connect
 from firebolt.model import FireboltBaseModel
 from firebolt.model.binding import Binding
 from firebolt.model.database import Database
@@ -156,6 +162,17 @@ class Engine(FireboltBaseModel):
             engine=self, database=database, is_default_engine=is_default_engine
         )
 
+    @check_attached_to_database
+    def get_connection(self) -> Connection:
+        """Get a connection to the attached database, for running queries."""
+        return connect(
+            engine_url=self.endpoint,
+            database=self.database.name,  # type: ignore # already checked by decorator
+            username=self._service.settings.user,
+            password=self._service.settings.password.get_secret_value(),
+            api_endpoint=self._service.settings.server,
+        )
+
     @check_attached_to_database
     def start(
         self,
@@ -252,7 +269,9 @@ class Engine(FireboltBaseModel):
 
     def _send_start(self) -> Engine:
         response = self._service.client.post(
-            url=f"/core/v1/account/engines/{self.engine_id}:start",
+            url=ACCOUNT_ENGINE_START_URL.format(
+                account_id=self._service.account_id, engine_id=self.engine_id
+            )
         )
         return Engine.parse_obj_with_service(
             obj=response.json()["engine"], engine_service=self._service
@@ -262,7 +281,9 @@ class Engine(FireboltBaseModel):
     def stop(self) -> Engine:
         """Stop an Engine running on Firebolt."""
         response = self._service.client.post(
-            url=f"/core/v1/account/engines/{self.engine_id}:stop",
+            url=ACCOUNT_ENGINE_STOP_URL.format(
+                account_id=self._service.account_id, engine_id=self.engine_id
+            )
         )
         return Engine.parse_obj_with_service(
             obj=response.json()["engine"], engine_service=self._service
@@ -271,9 +292,9 @@ class Engine(FireboltBaseModel):
     def delete(self) -> Engine:
         """Delete an Engine from Firebolt."""
         response = self._service.client.delete(
-            url=f"/core/v1"
-            f"/accounts/{self._service.account_id}"
-            f"/engines/{self.engine_id}",
+            url=ACCOUNT_ENGINE_URL.format(
+                account_id=self._service.account_id, engine_id=self.engine_id
+            ),
         )
         return Engine.parse_obj_with_service(
             obj=response.json()["engine"], engine_service=self._service
