@@ -2,6 +2,7 @@ from typing import Optional
 
 from firebolt.client import Client, log_request, log_response, raise_on_4xx_5xx
 from firebolt.common import Settings
+from firebolt.common.urls import ACCOUNT_BY_NAME_URL
 from firebolt.service.provider import get_provider_id
 
 
@@ -19,22 +20,25 @@ class ResourceManager:
     - instance types (AWS instance types which engines can use)
     """
 
-    def __init__(self, settings: Optional[Settings] = None):
-        if settings is None:
-            settings = Settings()
+    def __init__(
+        self, settings: Optional[Settings] = None, account_name: Optional[str] = None
+    ):
+        self.settings = settings or Settings()
 
         self.client = Client(
-            auth=(settings.user, settings.password.get_secret_value()),
-            base_url=f"https://{settings.server}",
-            api_endpoint=settings.server,
+            auth=(self.settings.user, self.settings.password.get_secret_value()),
+            base_url=f"https://{ self.settings.server}",
+            api_endpoint=self.settings.server,
         )
         self.client.event_hooks = {
             "request": [log_request],
             "response": [raise_on_4xx_5xx, log_response],
         }
-        self._init_services(default_region_name=settings.default_region)
 
-    def _init_services(self, default_region_name: str) -> None:
+        self.account_id = self._get_account_id(account_name=account_name)
+        self._init_services()
+
+    def _init_services(self) -> None:
         # avoid circular import
         from firebolt.service.binding import BindingService
         from firebolt.service.database import DatabaseService
@@ -43,10 +47,8 @@ class ResourceManager:
         from firebolt.service.instance_type import InstanceTypeService
         from firebolt.service.region import RegionService
 
-        # Cloud Platform Resources (AWS, etc)
-        self.regions = RegionService(
-            resource_manager=self, default_region_name=default_region_name
-        )
+        # Cloud Platform Resources (AWS)
+        self.regions = RegionService(resource_manager=self)
         self.instance_types = InstanceTypeService(resource_manager=self)
         self.provider_id = get_provider_id(client=self.client)
 
@@ -55,3 +57,17 @@ class ResourceManager:
         self.engines = EngineService(resource_manager=self)
         self.engine_revisions = EngineRevisionService(resource_manager=self)
         self.bindings = BindingService(resource_manager=self)
+
+    def _get_account_id(self, account_name: Optional[str]) -> str:
+        """
+        Given account_name, look up account_id. If account_name is None,
+        get the default account_id.
+
+        Args:
+            account_name: Name of the account.
+        """
+        if account_name is None:
+            return self.client.account_id
+        return self.client.get(
+            url=ACCOUNT_BY_NAME_URL, params={"account_name": account_name.lower()}
+        ).json()["account_id"]
