@@ -1,31 +1,26 @@
 from typing import Dict, List
 
-from firebolt.common.utils import cached_property
+from firebolt.common.urls import REGIONS_URL
+from firebolt.common.util import cached_property
 from firebolt.model.region import Region, RegionKey
 from firebolt.service.base import BaseService
 from firebolt.service.manager import ResourceManager
 
 
 class RegionService(BaseService):
-    def __init__(
-        self, resource_manager: ResourceManager, default_region_name: str = None
-    ):
+    def __init__(self, resource_manager: ResourceManager):
         """
         Service to manage AWS Regions (us-east-1, etc).
 
         Args:
             resource_manager: Resource manager to use.
-            default_region_name: AWS Region to use as a default.
         """
-        self.default_region_name = default_region_name
         super().__init__(resource_manager=resource_manager)
 
     @cached_property
     def regions(self) -> List[Region]:
         """List of available AWS Regions on Firebolt."""
-        response = self.client.get(
-            url="/compute/v1/regions", params={"page.first": 5000}
-        )
+        response = self.client.get(url=REGIONS_URL, params={"page.first": 5000})
         return [Region.parse_obj(i["node"]) for i in response.json()["edges"]]
 
     @cached_property
@@ -42,11 +37,11 @@ class RegionService(BaseService):
     def default_region(self) -> Region:
         """Default AWS Region, could be provided from environment."""
 
-        if not self.default_region_name:
+        if not self.settings.default_region:
             raise ValueError(
                 "The environment variable FIREBOLT_DEFAULT_REGION must be set."
             )
-        return self.get_by_name(name=self.default_region_name)
+        return self.get_by_name(name=self.settings.default_region)
 
     def get_by_name(self, name: str) -> Region:
         """Get an AWS region by its name (eg. us-east-1)."""
